import os
import fnmatch


def recursive_glob(treeroot, pattern):
    results = []
    for base, dirs, files in os.walk(treeroot):
        good_files = fnmatch.filter(files, pattern)
        results.extend(os.path.join(base, f) for f in good_files)
    return results


POS_FA_UNI = {'اسم': 'NOUN',
              'فعل': 'VERB',
              'حرف': 'INTJ',
              'صفت': 'ADJ',
              'تصدیق': 'ADP',
              'قید': 'ADV',
              'کمکی': 'AUX',
              'ربط هماهنگ کننده': 'CCONJ',
              'تعیین کننده': 'DET',
              'عدد': 'NUM',
              'ذره': 'PART',
              'ضمیر': 'PRON',
              'اسم خاص': 'PROPN',
              'نقطه گذاری': 'PUNCT',
              'ربط تبعی': 'SCONJ',
              'نماد': 'SYM',
              'دیگر': 'X'}


POS_UNI_FA = {'NOUN': 'اسم',
              'VERB': 'فعل',
              'INTJ': 'حرف',
              'ADJ': 'صفت',
              'ADP': 'تصدیق',
              'ADV': 'قید',
              'AUX': 'کمکی',
              'CCONJ': 'ربط هماهنگ کننده',
              'DET': 'تعیین کننده',
              'NUM': 'عدد',
              'PART': 'ذره',
              'PRON': 'ضمیر',
              'PROPN': 'اسم خاص',
              'PUNCT': 'نقطه گذاری',
              'SCONJ': 'ربط تبعی',
              'SYM': 'نماد',
              'X': 'دیگر'}

AYEH_SEMANTIC = './data/qSyntaxSemantic/'
AYEH_SYNTAX = './data/syntax_data/'
QURAN_ORDER = './data/quarn_order.csv'


AYEH_INDEX = ['حمد',
 'بقره',
 'ال عمران',
 'نساء',
 'مااده',
 'انعام',
 'اعراف',
 'انفال',
 'توبه',
 'يونس',
 'هود',
 'يوسف',
 'رعد',
 'ابراهيم',
 'حجر',
 'نحل',
 'اسراء',
 'كهف',
 'مريم',
 'طه',
 'انبياء',
 'حج',
 'مومنون',
 'نور',
 'فرقان',
 'شعراء',
 'نمل',
 'قصص',
 'عنكبوت',
 'روم',
 'لقمان',
 'سجده',
 'احزاب',
 'سبا',
 'فاطر',
 'يس',
 'صافات',
 'ص',
 'زمر',
 'غافر',
 'فصلت',
 'شوري',
 'زخرف',
 'دخان',
 'جاثيه',
 'احقاف',
 'محمد',
 'فتح',
 'حجرات',
 'ق',
 'ذاريات',
 'طور',
 'نجم',
 'قمر',
 'رحمان',
 'واقعه',
 'حديد',
 'مجادله',
 'حشر',
 'ممتحنه',
 'صف',
 'جمعه',
 'منافقون',
 'تغابن',
 'طلاق',
 'تحريم',
 'ملك',
 'قلم',
 'حاقه',
 'معارج',
 'نوح',
 'جن',
 'مزمل',
 'مدثر',
 'قيامت',
 'انسان',
 'مرسلات',
 'نبا',
 'نازعات',
 'عبس',
 'تكوير',
 'انفطار',
 'مطففين',
 'انشقاق',
 'بروج',
 'طارق',
 'اعلي',
 'غاشيه',
 'فجر',
 'بلد',
 'شمس',
 'ليل',
 'ضحي',
 'شرح',
 'تين',
 'علق',
 'قدر',
 'بينه',
 'زلزله',
 'عاديات',
 'قارعه',
 'تكاثر',
 'عصر',
 'همزه',
 'فيل',
 'قريش',
 'ماعون',
 'كوثر',
 'كافرون',
 'نصر',
 'مسد',
 'اخلاص',
 'فلق',
 'ناس']

# [
#     'حمد',
#     'بقره',
#     'ال عمران',
#     'نساء',
#     'مائده',
#     'انعام',
#     'اعراف',
#     'انفال',
#     'توبه',
#     'یونس',
#     'هود',
#     'یوسف',
#     'رعد',
#     'ابراهیم',
#     'حجر',
#     'نحل',
#     'إسراء',
#     'کهف',
#     'مریم',
#     'طه',
#     'أنبیاء',
#     'حجّ',
#     'مؤمنون',
#     'نور',
#     'فرقان',
#     'شعراء',
#     'نمل',
#     'قصص',
#     'عنکبوت',
#     'روم',
#     'لقمان',
#     'سجده',
#     'أحزاب',
#     'سبإ',
#     'فاطر',
#     'یس',
#     'صافّات',
#     'ص',
#     'زمر',
#     'غافر',
#     'فصلت',
#     'شوری',
#     'زخرف',
#     'دخان',
#     'جاثیه',
#     'احقاف',
#     'محمّد',
#     'فتح',
#     'حجرات',
#     'ق',
#     'ذاریات',
#     'طور',
#     'نجم',
#     'قمر',
#     'رحمان',
#     'واقعه',
#     'حدید',
#     'مجادله',
#     'حشر',
#     'ممتحنه',
#     'صفّ',
#     'جمعه',
#     'منافقون',
#     'تغابن',
#     'طلاق',
#     'تحریم',
#     'مُلک',
#     'قلم',
#     'حاقّه',
#     'معارج',
#     'نوح',
#     'جنّ',
#     'مزّمّل',
#     'مدّثّر',
#     'قیامت',
#     'إنسان',
#     'مرسلات',
#     'نبأ',
#     'نازعات',
#     'عبس',
#     'تکویر',
#     'انفطار',
#     'مطففین',
#     'انشقاق',
#     'بروج',
#     'طارق',
#     'أعلی',
#     'غاشیه',
#     'فجر',
#     'بلد',
#     'شمس',
#     'لیل',
#     'ضحی',
#     'شرح',
#     'تین',
#     'علق',
#     'قدر',
#     'بینه',
#     'زلزله',
#     'عادیات',
#     'قارعه',
#     'تکاثر',
#     'عصر',
#     'همزه',
#     'فیل',
#     'قریش',
#     'ماعون',
#     'کوثر',
#     'کافرون',
#     'نصر',
#     'مسد',
#     'اخلاص',
#     'فلق',
#     'ناس'
# ]
